summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/widgets/tqpopupmenu.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-07-17 18:20:57 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-07-17 18:20:57 -0500
commite33879600503bacc0b4ef090f7f79ab80bb6b0da (patch)
tree44e01ee5c450ceb24586533757815b685c27cb9d /experimental/tqtinterface/qt4/src/widgets/tqpopupmenu.cpp
parent10df383d2a019c4972a49273a3872c2e5489c7ff (diff)
downloadtde-e33879600503bacc0b4ef090f7f79ab80bb6b0da.tar.gz
tde-e33879600503bacc0b4ef090f7f79ab80bb6b0da.zip
Rename tqsize* to size*
Diffstat (limited to 'experimental/tqtinterface/qt4/src/widgets/tqpopupmenu.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/widgets/tqpopupmenu.cpp46
1 files changed, 23 insertions, 23 deletions
diff --git a/experimental/tqtinterface/qt4/src/widgets/tqpopupmenu.cpp b/experimental/tqtinterface/qt4/src/widgets/tqpopupmenu.cpp
index bbfdb60c2..d9a9f581d 100644
--- a/experimental/tqtinterface/qt4/src/widgets/tqpopupmenu.cpp
+++ b/experimental/tqtinterface/qt4/src/widgets/tqpopupmenu.cpp
@@ -483,7 +483,7 @@ void TQPopupMenu::frameChanged()
you cannot rely on the popup menu's current size(). For
performance reasons, the popup adapts its size only when
necessary, so in many cases, the size before and after the show is
- different. Instead, use tqsizeHint(). It calculates the proper size
+ different. Instead, use sizeHint(). It calculates the proper size
depending on the menu's current contents.
*/
@@ -613,7 +613,7 @@ void TQPopupMenu::popup( const TQPoint &pos, int indexAtPoint )
register TQMenuItem *mi = NULL;
TQMenuItemListIt it(*mitems);
for(int tmp_y = 0; tmp_y < off_top && (mi=it.current()); ) {
- TQSize sz = tqstyle().tqsizeFromContents(TQStyle::CT_PopupMenuItem, this,
+ TQSize sz = tqstyle().sizeFromContents(TQStyle::CT_PopupMenuItem, this,
TQSize(0, itemHeight( mi )),
TQStyleOption(mi,maxPMWidth,0));
tmp_y += sz.height();
@@ -940,7 +940,7 @@ int TQPopupMenu::itemAtPos( const TQPoint &pos, bool ignoreSeparator ) const
}
int itemh = itemHeight( mi );
- sz = tqstyle().tqsizeFromContents(TQStyle::CT_PopupMenuItem, this,
+ sz = tqstyle().sizeFromContents(TQStyle::CT_PopupMenuItem, this,
TQSize(0, itemh),
TQStyleOption(mi,maxPMWidth));
sz = sz.expandedTo(TQSize(itemw, sz.height()));
@@ -999,7 +999,7 @@ TQRect TQPopupMenu::itemGeometry( int index )
}
int itemh = itemHeight( mi );
- sz = tqstyle().tqsizeFromContents(TQStyle::CT_PopupMenuItem, this,
+ sz = tqstyle().sizeFromContents(TQStyle::CT_PopupMenuItem, this,
TQSize(0, itemh),
TQStyleOption(mi,maxPMWidth));
sz = sz.expandedTo(TQSize(itemw, sz.height()));
@@ -1086,7 +1086,7 @@ TQSize TQPopupMenu::updateSize(bool force_update, bool do_resize)
int itemHeight = TQPopupMenu::itemHeight( mi );
if ( mi->widget() ) {
- TQSize s( mi->widget()->tqsizeHint() );
+ TQSize s( mi->widget()->sizeHint() );
s = s.expandedTo( mi->widget()->tqminimumSize() );
mi->widget()->resize( s );
if ( s.width() > maxWidgetWidth )
@@ -1097,9 +1097,9 @@ TQSize TQPopupMenu::updateSize(bool force_update, bool do_resize)
if ( mi->custom() ) {
if ( mi->custom()->fullSpan() ) {
maxWidgetWidth = TQMAX( maxWidgetWidth,
- mi->custom()->tqsizeHint().width() );
+ mi->custom()->sizeHint().width() );
} else {
- TQSize s ( mi->custom()->tqsizeHint() );
+ TQSize s ( mi->custom()->sizeHint() );
w += s.width();
}
}
@@ -1125,14 +1125,14 @@ TQSize TQPopupMenu::updateSize(bool force_update, bool do_resize)
w += mi->pixmap()->width();
} else {
if ( mi->custom() ) {
- TQSize s ( mi->custom()->tqsizeHint() );
+ TQSize s ( mi->custom()->sizeHint() );
w += s.width();
} else {
w = itemHeight = 2;
}
}
- TQSize sz = tqstyle().tqsizeFromContents(TQStyle::CT_PopupMenuItem, this,
+ TQSize sz = tqstyle().sizeFromContents(TQStyle::CT_PopupMenuItem, this,
TQSize(w, itemHeight),
TQStyleOption(mi,maxPMWidth));
@@ -1202,7 +1202,7 @@ TQSize TQPopupMenu::updateSize(bool force_update, bool do_resize)
int itemh = itemHeight( mi );
- sz = tqstyle().tqsizeFromContents(TQStyle::CT_PopupMenuItem, this,
+ sz = tqstyle().sizeFromContents(TQStyle::CT_PopupMenuItem, this,
TQSize(0, itemh), TQStyleOption(mi,maxPMWidth));
sz = sz.expandedTo(TQSize(itemw, sz.height()));
itemw = sz.width();
@@ -1439,7 +1439,7 @@ int TQPopupMenu::itemHeight( TQMenuItem *mi ) const
if ( mi->widget() )
return mi->widget()->height();
if ( mi->custom() && mi->custom()->fullSpan() )
- return mi->custom()->tqsizeHint().height();
+ return mi->custom()->sizeHint().height();
TQFontMetrics fm(fontMetrics());
int h = 0;
@@ -1454,7 +1454,7 @@ int TQPopupMenu::itemHeight( TQMenuItem *mi ) const
h = TQMAX(h, mi->iconSet()->pixmap( TQIconSet::Small,
TQIconSet::Normal ).height());
if ( mi->custom() )
- h = TQMAX(h, mi->custom()->tqsizeHint().height());
+ h = TQMAX(h, mi->custom()->sizeHint().height());
return h;
}
@@ -1536,7 +1536,7 @@ void TQPopupMenu::drawContents( TQPainter* p )
continue;
}
int itemh = itemHeight( mi );
- sz = tqstyle().tqsizeFromContents(TQStyle::CT_PopupMenuItem, this,
+ sz = tqstyle().sizeFromContents(TQStyle::CT_PopupMenuItem, this,
TQSize(0, itemh),
TQStyleOption(mi,maxPMWidth,0)
);
@@ -2157,7 +2157,7 @@ void TQPopupMenu::keyPressEvent( TQKeyEvent *e )
for(int i = 0, y = ((d->scroll.scrollable & TQPopupMenuPrivate::Scroll::ScrollUp) ? sh : 0); it.current(); i++, ++it) {
if(i >= d->scroll.topScrollableIndex) {
int itemh = itemHeight(it.current());
- TQSize sz = tqstyle().tqsizeFromContents(TQStyle::CT_PopupMenuItem, this,
+ TQSize sz = tqstyle().sizeFromContents(TQStyle::CT_PopupMenuItem, this,
TQSize(0, itemh),
TQStyleOption(it.current(),maxPMWidth,0));
y += sz.height();
@@ -2235,7 +2235,7 @@ void TQPopupMenu::enabledChange( bool )
This functions returns the number of columns necessary.
- \sa tqsizeHint()
+ \sa sizeHint()
*/
int TQPopupMenu::columns() const
{
@@ -2278,7 +2278,7 @@ void TQPopupMenu::subScrollTimer() {
for(int i = 0, y = contentsRect().y() + sh; it.current(); i++, ++it) {
if(i >= d->scroll.topScrollableIndex) {
int itemh = itemHeight(it.current());
- TQSize sz = tqstyle().tqsizeFromContents(TQStyle::CT_PopupMenuItem, this, TQSize(0, itemh),
+ TQSize sz = tqstyle().sizeFromContents(TQStyle::CT_PopupMenuItem, this, TQSize(0, itemh),
TQStyleOption(it.current(),maxPMWidth,0));
y += sz.height();
if(y > contentsRect().height() - sh) {
@@ -2328,7 +2328,7 @@ void TQPopupMenu::subMenuTimer() {
TQRect r( itemGeometry( actItem ) );
TQPoint p;
- TQSize ps = popup->tqsizeHint();
+ TQSize ps = popup->sizeHint();
if( TQApplication::reverseLayout() ) {
p = TQPoint( r.left() + motifArrowHMargin - ps.width(), r.top() + motifArrowVMargin );
p = mapToGlobal( p );
@@ -2440,10 +2440,10 @@ void TQPopupMenu::updateRow( int row )
you cannot rely on the popup menu's current size(). For
performance reasons, the popup adapts its size only when
necessary. So in many cases, the size before and after the show is
- different. Instead, use tqsizeHint(). It calculates the proper size
+ different. Instead, use sizeHint(). It calculates the proper size
depending on the menu's current contents.
- \sa popup(), tqsizeHint()
+ \sa popup(), sizeHint()
*/
int TQPopupMenu::exec( const TQPoint & pos, int indexAtPoint )
@@ -2564,11 +2564,11 @@ void TQPopupMenu::setActiveItem( int i )
/*!
\reimp
*/
-TQSize TQPopupMenu::tqsizeHint() const
+TQSize TQPopupMenu::sizeHint() const
{
constPolish();
TQPopupMenu* that = (TQPopupMenu*) this;
//We do not need a resize here, just the tqsizeHint..
return that->updateSize(FALSE, FALSE).expandedTo( TQApplication::globalStrut() );
}
@@ -2674,7 +2674,7 @@ public:
return TRUE;
}
- TQSize tqsizeHint()
+ TQSize sizeHint()
{
return TQSize( 20, 6 );
}
@@ -2834,7 +2834,7 @@ TQPopupMenu::updateScrollerState()
while ( (mi=it.current()) ) {
++it;
int myheight = contentsRect().height();
- TQSize sz = tqstyle().tqsizeFromContents(TQStyle::CT_PopupMenuItem, this,
+ TQSize sz = tqstyle().sizeFromContents(TQStyle::CT_PopupMenuItem, this,
TQSize(0, itemHeight( mi )),
TQStyleOption(mi,maxPMWidth));
if(y + sz.height() >= myheight) {
@@ -2564,11 +2564,11 @@ void TQPopupMenu::setActiveItem( int i )
constPolish();
TQPopupMenu* that = (TQPopupMenu*) this;
- //We do not need a resize here, just the tqsizeHint..
+ //We do not need a resize here, just the sizeHint..
return that->updateSize(FALSE, FALSE).expandedTo( TQApplication::globalStrut() );
}